==> django-froala-editor-1.2.3.tar.gz: django-froala-editor-1.2.3/froala_editor/static/froala_editor/js/langs/da.js <==
/*!
 * froala_editor v1.2.3 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Danish
 */

$.Editable.LANGS['da'] = {
  translation: {
    "Bold": "Fed",
    "Italic": "Kursiv",
    "Underline": "Understreg",
    "Strikethrough": "Gennemstreg",
    "Font Size": "Skriftst\u00f8rrelse",
    "Color": "Farve",
    "Background": "Baggrunds",
    "Text": "Tekst",
    "Format Block": "Formater",
    "Normal": "Normal",
    "Paragraph": "S\u00e6tning",
    "Code": "Code",
    "Quote": "Indrykning",
    "Heading 1": "Overskrift 1",
    "Heading 2": "Overskrift 2",
    "Heading 3": "Overskrift 3",
    "Heading 4": "Overskrift 4",
    "Heading 5": "Overskrift 5",
    "Heading 6": "Overskrift 6",
    "Block Style": "Blok stil",
    "Alignment": "Tilpasning",
    "Align Left": "Venstrejusteret",
    "Align Center": "Centreret",
    "Align Right": "H\u00f8jrejusteret",
    "Justify": "Justering",
    "Numbered List": "Nummerering",
    "Bulleted List": "Punkt tegn",
    "Indent Less": "Formindsk indrykning",
    "Indent More": "For\u00f8g indrykning",
    "Select All": "V\u00e6lg alle",
    "Insert Link": "Inds\u00e6t link",
    "Insert Image": "Inds\u00e6t billede",
    "Insert Video": "Inds\u00e6t video",
    "Undo": "Fortryd",
    "Redo": "Genopret",
    "Show HTML": "Vis HTML",
    "Float Left": "Venstre",
    "Float None": "Ingen",
    "Float Right": "H\u00f8jre",
    "Replace Image": "Udskift billedet",
    "Remove Image": "Fjern billede",
    "Title": "Titel",
    "Drop image": "Dr\u00e5be billede",
    "or click": "eller klik p\u00e5",
    "or": "eller",
    "Enter URL": "Indtast URL",
    "Please wait!": "Vent venligst!",
    "Are you sure? Image will be deleted.": "Er du sikker? Billede vil blive slettet.",
    "UNLINK": "Fjern link",
    "Open in new tab": "\u00c5bn i ny fane",
    "Type something": "Skriv noget",
    "Cancel": "Fortryd",
    "OK": "Ok",
    "Manage images": "Administrer billeder",
    "Delete": "Slet",
    "Font Family": "Skrifttype",
    "Insert Horizontal Line": "Inds\u00e6t vandret linie",
    "Table": "Tabel",
    "Insert table": "Inds\u00e6t tabel",
    "Cell": "Celle",
    "Row": "R\u00e6kke",
    "Column": "Kolonne",
    "Delete table": "Slet tabel",
    "Insert cell before": "Inds\u00e6t celle f\u00f8r",
    "Insert cell after": "Inds\u00e6t celle efter",
    "Delete cell": "Slet celle",
    "Merge cells": "Flet celler",
    "Horizontal split": "Vandret split",
    "Vertical split": "Lodret split",
    "Insert row above": "Inds\u00e6t r\u00e6kke over",
    "Insert row below": "Inds\u00e6t r\u00e6kke under",
    "Delete row": "Slet r\u00e6kke",
    "Insert column before": "Inds\u00e6t kolonne f\u00f8r",
    "Insert column after": "Inds\u00e6t kolonne efter",
    "Delete column": "Slet kolonne"
  },
  direction: "ltr"
};

==> django-froala-editor-1.2.4.1.tar.gz: django-froala-editor-1.2.4.1/froala_editor/static/froala_editor/js/langs/da.js <==
/*!
 * froala_editor v1.2.4 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Danish
 */

$.Editable.LANGS['da'] = {
  translation: {
    "Bold": "Fed",
    "Italic": "Kursiv",
    "Underline": "Understreg",
    "Strikethrough": "Gennemstreg",
    "Font Size": "Skriftst\u00f8rrelse",
    "Color": "Farve",
    "Background": "Baggrunds",
    "Text": "Tekst",
    "Format Block": "Formater",
    "Normal": "Normal",
    "Paragraph": "S\u00e6tning",
    "Code": "Code",
    "Quote": "Indrykning",
    "Heading 1": "Overskrift 1",
    "Heading 2": "Overskrift 2",
    "Heading 3": "Overskrift 3",
    "Heading 4": "Overskrift 4",
    "Heading 5": "Overskrift 5",
    "Heading 6": "Overskrift 6",
    "Block Style": "Blok stil",
    "Alignment": "Tilpasning",
    "Align Left": "Venstrejusteret",
    "Align Center": "Centreret",
    "Align Right": "H\u00f8jrejusteret",
    "Justify": "Justering",
    "Numbered List": "Nummerering",
    "Bulleted List": "Punkt tegn",
    "Indent Less": "Formindsk indrykning",
    "Indent More": "For\u00f8g indrykning",
    "Select All": "V\u00e6lg alle",
    "Insert Link": "Inds\u00e6t link",
    "Insert Image": "Inds\u00e6t billede",
    "Insert Video": "Inds\u00e6t video",
    "Undo": "Fortryd",
    "Redo": "Genopret",
    "Show HTML": "Vis HTML",
    "Float Left": "Venstre",
    "Float None": "Ingen",
    "Float Right": "H\u00f8jre",
    "Replace Image": "Udskift billedet",
    "Remove Image": "Fjern billede",
    "Title": "Titel",
    "Drop image": "Dr\u00e5be billede",
    "or click": "eller klik p\u00e5",
    "or": "eller",
    "Enter URL": "Indtast URL",
    "Please wait!": "Vent venligst!",
    "Are you sure? Image will be deleted.": "Er du sikker? Billede vil blive slettet.",
    "UNLINK": "Fjern link",
    "Open in new tab": "\u00c5bn i ny fane",
    "Type something": "Skriv noget",
    "Cancel": "Fortryd",
    "OK": "Ok",
    "Manage images": "Administrer billeder",
    "Delete": "Slet",
    "Font Family": "Skrifttype",
    "Insert Horizontal Line": "Inds\u00e6t vandret linie",
    "Table": "Tabel",
    "Insert table": "Inds\u00e6t tabel",
    "Cell": "Celle",
    "Row": "R\u00e6kke",
    "Column": "Kolonne",
    "Delete table": "Slet tabel",
    "Insert cell before": "Inds\u00e6t celle f\u00f8r",
    "Insert cell after": "Inds\u00e6t celle efter",
    "Delete cell": "Slet celle",
    "Merge cells": "Flet celler",
    "Horizontal split": "Vandret split",
    "Vertical split": "Lodret split",
    "Insert row above": "Inds\u00e6t r\u00e6kke over",
    "Insert row below": "Inds\u00e6t r\u00e6kke under",
    "Delete row": "Slet r\u00e6kke",
    "Insert column before": "Inds\u00e6t kolonne f\u00f8r",
    "Insert column after": "Inds\u00e6t kolonne efter",
    "Delete column": "Slet kolonne",
    "Uploading image": "Uploader billede",
    "Upload File": "Upload fil",
    "Drop File": "Drop fil",
    "Clear formatting": "Fjern formatering"
  },
  direction: "ltr"
};
